Example that goes with [introductory blog post](https://blog.dagworks.io/p/burr-develop-stateful-ai-applications).

## 🏃Quick start

```bash
pip install "burr[start]" jupyter
```

Run the notebook:

```bash
jupyter notebook
```

Then open `blog.ipynb` and run the cells.
